Handle case when there are no vserver-* packages properly
[sliceimage.git] / build.sh
index 63ede95..f1a0657 100755 (executable)
--- a/build.sh
+++ b/build.sh
@@ -37,6 +37,10 @@ pl_process_fedora_options $@
 shiftcount=$?
 shift $shiftcount
 
+# pldistro expected as $1 - defaults to planetlab
+pldistro=planetlab
+[ -n "$@" ] && pldistro=$1
+
 # Do not tolerate errors
 set -e
 
@@ -52,35 +56,32 @@ vrefname=default
 vref=${vrefdir}/${vrefname}
 install -d -m 755 ${vref}
 
-# "Parse" out the packages and groups for mkfedora
-vrefpackages=$(grep "^package:.*" vserver-reference.lst | awk '{print $2}')
-vrefgroups=$(grep "^group:.*" vserver-reference.lst | awk '{print $2}')
-options=""
-for package in ${vrefpackages} ; do  options="$options -p $package"; done
-for group in ${vrefgroups} ; do options="$options -g $group"; done
+# locate the packages and groups file
+pkgsfile=$(pl_locateDistroFile ../build/ ${pldistro} vserver.pkgs)
 
-# Populate a minimal /dev in the reference image
-pl_makedevs ${vref}
+# Some of the PlanetLab RPMs attempt to (re)start themselves in %post,
+# unless the installation is running inside the BootCD environment. We
+# would like to pretend that we are.
+export PL_BOOTCD=1
 
 # Populate image with vserver-reference packages
-pl_setup_chroot ${vref} ${options}
+pl_root_setup_chroot ${vref} -k -f $pkgsfile
 
-for systemvserver in reference-vservers/*.lst ; do
-    NAME=$(basename $systemvserver .lst)
+systemvserver_count=$(ls ../build/config.${pldistro}/vserver-*.pkgs 2> /dev/null | wc -l)
+[ $systemvserver_count -gt 0 ] && for systemvserver in $(ls ../build/config.${pldistro}/vserver-*.pkgs) ; do
+    NAME=$(basename $systemvserver .pkgs | sed -e s,vserver-,,)
 
     echo "--------START BUILDING system vserver ${NAME}: $(date)"
 
     # "Parse" out the packages and groups for yum
-    systempackages=$(grep "^package:.*" $systemvserver | awk '{print $2}')
-    systemgroups=$(grep "^group:.*" $systemvserver | awk '{print $2}')
+    systempackages=$(pl_getPackages ${pl_DISTRO_NAME} $systemvserver)
+    systemgroups=$(pl_getGroups ${pl_DISTRO_NAME} $systemvserver)
 
     vdir=${vstubdir}/${NAME}
     rm -rf ${vdir}/*
     install -d -m 755 ${vdir}
 
     # Clone the base vserver reference to the system vserver reference
-
-       # OPTIMIZATION: Consider using "cp -al" in the future
     (cd ${vref} && find . | cpio -m -d -u -p ${vdir})
     rm -f ${vdir}/var/lib/rpm/__db*